#
# spec file for package ecryptfs-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define sbindir /sbin
%else
%define sbindir %{_sbindir}
%endif

%define lname   libecryptfs1
Name:           ecryptfs-utils
Version:        111
Release:        9.2
Summary:        Userspace Utilities for ecryptfs
License:        GPL-2.0-only
Group:          Productivity/Security
URL:            https://ecryptfs.org/
Source0:        https://launchpad.net/ecryptfs/trunk/%{version}/+download/ecryptfs-utils_%{version}.orig.tar.gz
Source1:        baselibs.conf
Source2:        ecryptfs-mount-private.png
# PATCH-FIX-OPENSUSE fix for systemd and no UUID in fstab
Patch0:         ecryptfs-setup-swap-SuSE.patch
# PATCH-FIX-OPENSUSE build with -fpie/-pie
Patch1:         ecryptfs-utils-src-utils-Makefile.patch
Patch2:         ecryptfs-utils-openssl11.patch
Patch3:         ecryptfs-usrmerge.diff
Patch4:         ecryptfs-fix-gcc14.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  keyutils-devel
BuildRequires:  keyutils-libs
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  mozilla-nss-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-config
BuildRequires:  pam-devel
BuildRequires:  pkcs11-helper-devel
BuildRequires:  pkg-config
#BuildRequires:  python3-devel
#BuildRequires:  swig
BuildRequires:  trousers-devel
BuildRequires:  update-desktop-files
Requires(pre):  pam-config
Requires(pre):  permissions
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A stacked cryptographic filesystem for Linux.

%package -n %{lname}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n %{lname}
A stacked cryptographic filesystem for Linux.

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       %{lname} = %{version}

%description devel
A stacked cryptographic filesystem for Linux.

%prep
%autosetup -p1

%build
export RPM_OPT_FLAGS="%{optflags} -fno-strict-aliasing"
autoreconf -fiv
%configure \
	rootsbindir=%{sbindir} \
	--docdir=%{_defaultdocdir}/%{name} \
	--disable-static \
	--disable-pywrap \
	--enable-tspi \
	--enable-pkcs11-helper \
	--with-pamdir=%{_pamdir}
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
mkdir -p %{buildroot}/%{_datadir}/applications
install -m644 %{SOURCE2} %{buildroot}%{_datadir}/%{name}/ecryptfs-mount-private.png
printf "Encoding=UTF-8\n" >>%{buildroot}/%{_datadir}/%{name}/ecryptfs-mount-private.desktop
printf "Encoding=UTF-8\n" >>%{buildroot}/%{_datadir}/%{name}/ecryptfs-setup-private.desktop
printf "Icon=%{_datadir}/%{name}/ecryptfs-mount-private.png\n" >>%{buildroot}/%{_datadir}/%{name}/ecryptfs-mount-private.desktop
printf "Icon=%{_datadir}/%{name}/ecryptfs-mount-private.png\n" >>%{buildroot}/%{_datadir}/%{name}/ecryptfs-setup-private.desktop
sed -i 's|^_||' %{buildroot}/%{_datadir}/%{name}/ecryptfs-mount-private.desktop
sed -i 's|^_||' %{buildroot}/%{_datadir}/%{name}/ecryptfs-setup-private.desktop
mv %{buildroot}/%{_datadir}/%{name}/ecryptfs-setup-private.desktop %{buildroot}/%{_datadir}/applications
%suse_update_desktop_file %{buildroot}/%{_datadir}/%{name}/ecryptfs-mount-private.desktop
%suse_update_desktop_file -r ecryptfs-setup-private System Security
%find_lang %{name}
# replace duplicate files by symlinks
%fdupes -s %{buildroot}
# do not ship .la files
find %{buildroot} -type f -name "*.la" -delete -print

#we need ecryptfs kernel module
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d/
echo -e "# ecryptfs module is needed before ecryptfs mount, so mount helper can \n# check for file name encryption support\necryptfs" >%{buildroot}%{_prefix}/lib/modules-load.d/ecryptfs.conf

%verifyscript
%verify_permissions -e %{sbindir}/mount.ecryptfs_private

%post
%set_permissions %{sbindir}/mount.ecryptfs_private
%{_sbindir}/pam-config -a --ecryptfs
%desktop_database_post

%post -n %{lname} -p /sbin/ldconfig

%postun
if [ "$1" -eq 0 ]; then
	%{_sbindir}/pam-config -d --ecryptfs
fi
%desktop_database_postun

%postun -n %{lname} -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-, root, root)
%doc COPYING NEWS README THANKS doc/ecryptfs-faq.html
%{_docdir}/%{name}
%{_bindir}/*
%{sbindir}/mount.ecryptfs
%{sbindir}/umount.ecryptfs
%{sbindir}/umount.ecryptfs_private
%verify(not mode) %{sbindir}/mount.ecryptfs_private
%{_mandir}/man1/*ecryptfs*
%{_mandir}/man7/ecryptfs*
%{_mandir}/man8/*ecryptfs*
%{_libdir}/ecryptfs*
%{_datadir}/ecryptfs-utils
%{_pamdir}/pam_ecryptfs.so
#{python_sitelib}/ecryptfs-utils
#{python_sitearch}/ecryptfs-utils
%{_datadir}/applications/*.desktop
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/*

%files -n %{lname}
%defattr(-, root, root)
%{_libdir}/libecryptfs.so.*

%files devel
%defattr(-, root, root)
%{_includedir}/ecryptfs.h
%{_libdir}/libecryptfs.so
%{_libdir}/pkgconfig/libecryptfs.pc

%changelog
* Mon May  6 2024 Marcus Meissner <meissner@suse.com>
- ecryptfs-fix-gcc14.patch: fix build with gcc14
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
- Rebase ecryptfs-utils-openssl11.patch: make it apply with patch
  - p1 like all the others.
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Tue May  3 2022 Marcus Meissner <meissner@suse.com>
- use https urls
* Thu Feb  4 2021 Ludwig Nussel <lnussel@suse.de>
- usr %%_pamdir
* Tue Nov 17 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
  - added: ecryptfs-usrmerge.diff
* Tue Aug 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix wrong usage of %%{_libexecdir} for systemd owned paths below
  %%{_prefix}/lib.
* Wed Feb 21 2018 meissner@suse.com
- drop python2 support (needs to be replaced by python3 support)
  (bsc#1081587)
* Tue Nov 14 2017 meissner@suse.com
- The license is GPL-2.0 (without + / or later)
* Tue Nov  7 2017 vcizek@suse.com
- Update to 111
  * upstream provides no changelog
- add ecryptfs-utils-openssl11.patch to support build with
  OpenSSL 1.1 (bsc#1066937)
* Tue Nov  7 2017 vcizek@suse.com
- drop validate-mount-destination-fs-type.patch (upstream)
* Thu Mar  9 2017 sfalken@opensuse.org
- Edited %%files section to clear unpackaged files builderror in
  openSUSE:Factory
* Wed Jan 20 2016 meissner@suse.com
- validate-mount-destination-fs-type.patch: A local user could have
  escalated privileges by mounting over special filesystems (bsc#962052
  CVE-2016-1572)
* Sat Oct 17 2015 mpluskal@suse.com
- Update to 108
  * This release does not have a changelog.
* Fri Oct  2 2015 mpluskal@suse.com
- Do not ship .la files
* Wed Sep 30 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update autotool dependencies
- Split library and devel packages
- Use desktop file macros
- Use fdupes to reduce duplicities
* Mon May 11 2015 meissner@suse.com
- updated to 106
  - new passphrase wrapping method, including the salt to fix
    CVE-2014-9687 / bsc#920160
  - various bugfixes
* Thu Sep  4 2014 darin@darins.net
- update to 104
  - lots of bugfixes, apparently from static code checking
* Fri Aug  8 2014 fcrozat@suse.com
- Drop ecryptfs-correct-desktop.patch and ensure
  ecryptfs-mount-private.desktop is properly generated and
  installed in a program specific location (ecryptfs-setup-private
  will take care of creating the right symlink) and not in
  /usr/share/applications by default.
- Add ecryptfs-mount-private.png (from Fedora)
- Create tmpfiles.d to ensure ecryptfs module is autoloaded at
  start.
- Fix category on ecryptfs-setup-private.desktop.
* Thu Aug 15 2013 darin@darins.net
- fix %%postun to not run pam-config on update (bnc#814098, bnc#834993)
* Mon Aug  5 2013 darin@darins.net
- update to 103
- move -pie/-fpie into separate patch
- update ecryptfs-setup-swap-SuSE.patch for systmd and fstab
  without UUID lables
- remove ecryptfs-utils.security.patch, fixed upstream
- add PreReq: permissions
- removed unpackaged doc
* Wed Jul 11 2012 meissner@suse.com
- also supply MS_NODEV to avoid exposing device files
  if someone got them on the encrypted media.
* Tue Jul 10 2012 meissner@suse.com
- point the desktop link to the right .desktop file
- build mount.ecryptfs_private with -pie/-fpie
* Wed Jul  4 2012 meissner@suse.com
- hook pam_ecryptfs into pam session and auth bnc#755475
* Thu Jun 21 2012 meissner@suse.com
- added security improvements to mount.ecryptfs_private
  and pam_ecryptfs (bnc#740110)
* Fri Apr  6 2012 darin@darins.net
- patch so ecryptfs-setup-swap executes boot.crypto
* Wed Mar 28 2012 meissner@suse.com
- updated to 96
  - bugfixes
  - testsuite added
  - ecryptfs-verify utility added
  - write-read test utility
- mark /sbin/mount.eccryptfs_private as setuidable (bnc#745584 , bnc#740110)
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Sep 20 2011 meissner@suse.de
- Updated to 92
  * Fix umask issue introduced by last security update
  * some bugfixes
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Put make call in the right spot
- Use %%_smp_mflags for parallel build
* Thu Aug 11 2011 meissner@suse.de
- Updated to 90
  Fixed several security issues:
  * CVE-2011-1831 - Race condition when checking mountpoint during mount.
  * CVE-2011-1832 - Race condition when checking mountpoint during unmount.
  * CVE-2011-1833 - Race condition when checking source during mount.
  * CVE-2011-1834 - Improper mtab handling allowing corruption due to resource
    limits, signals, etc.
  * CVE-2011-1835 - Key poisoning in ecryptfs-setup-private due to insecure temp
    directory.
  * CVE-2011-1836 - ecryptfs-recover-private mounts directly in /tmp
  * CVE-2011-1837 - Predictable lock counter name and associated races.
  New ecryptfs-find binary to find by inode.
* Mon Apr 18 2011 meissner@suse.de
- Updated to 87
  * src/utils/ecryptfs-setup-private: update the Private.* selinux
    contexts
  * src/utils/ecryptfs-setup-private:
  - add -p to mkdir, address noise for a non-error
  - must insert keys during testing phase, since we remove keys on
    unmount now, LP: #725862
  * src/utils/ecryptfs_rewrap_passphrase.c: confirm passphrases in
    interactive mode, LP: #667331
- Updated to 86
  * src/pam_ecryptfs/pam_ecryptfs.c:
  - check if this file exists and ask the user for the wrapping passphrase
    if it does
  - eliminate both ecryptfs_pam_wrapping_independent_set() and
    ecryptfs_pam_automount_set() and replace with a reusable
    file_exists_dotecryptfs() function
  * src/utils/mount.ecryptfs_private.c:
  - support multiple, user configurable private directories by way of
    a command line "alias" argument
  - this "alias" references a configuration file by the name of:
    $HOME/.ecryptfs/alias.conf, which is in an fstab(5) format,
    as well as $HOME/.ecryptfs/alias.sig, in the same format as
    Private.sig
  - if no argument specified, the utility operates in legacy mode,
    defaulting to "Private"
  - rename variables, s/dev/src/ and s/mnt/dest/
  - add a read_config() function
  - add an alias char* to replace the #defined ECRYPTFS_PRIVATE_DIR
  - this is half of the fix to LP: #615657
  * doc/manpage/mount.ecryptfs_private.1: document these changes
  * src/libecryptfs/main.c, src/utils/mount.ecryptfs_private.c:
  - allow umount.ecryptfs_private to succeed when the key is no
    longer in user keyring.
- Updated to 85
  * src/utils/ecryptfs-recover-private: clean sigs of invalid characters
  * src/utils/mount.ecryptfs_private.c:
  - fix bug LP: #313812, clear used keys on unmount
  - add ecryptfs_unlink_sigs to the mount opts, so that unmounts from
    umount.ecryptfs behave similarly
  - use ecryptfs_remove_auth_tok_from_keyring() on the sig and sig_fnek
  * src/utils/ecryptfs-migrate-home:
  - support user databases outside of /etc/passwd, LP: #627506
- Updated to 84
  * src/desktop/ecryptfs-record-passphrase: fix typo, LP: #524139
  * debian/rules, debian/control:
  - disable the gpg key module, as it's not yet functional
  - clean up unneeded build-deps
  - also, not using opencryptoki either
  * doc/manpage/ecryptfs.7: fix minor documentation bug, reported by
    email by Jon 'maddog' Hall
  * doc/manpage/ecryptfs-recover-private.1, doc/manpage/Makefile.am,
    po/POTFILES.in, src/utils/ecryptfs-recover-private,
    src/utils/Makefile.am: add a utility to simplify data recovery
    of an encrypted private directory from a Live ISO, LP: #689969
* Sat Apr 10 2010 aj@suse.de
- Fix build with adding requires on mozilla-nss-devel and python-devel.
- Fix package list.
* Thu Mar 18 2010 meissner@suse.de
- Updated to 83
  - lots of bugfixes
  - improvements
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Thu Jun 25 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Fri Oct 24 2008 meissner@suse.de
- Upgraded to version 61
  - starts of filename encryption
  - bugfixes
* Fri Sep 19 2008 meissner@suse.de
- Upgraded to version 58
  - config file changes yet again
  - some documentation fixes
  - some TPM related fixes
* Sat Aug 23 2008 meissner@suse.de
- Upgraded to version 56
  - more manpages
  - changed configfile format
* Fri Jul 11 2008 meissner@suse.de
- Upgraded to version 50
  - another manpage
  - bugfixes
  - fixed kernel netlink interface
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 meissner@suse.de
- Upgraded to version 41
  - typo fixed in manpage
- enabled TPM support (tspi)
- enabled PKCS11 support
* Mon Feb 25 2008 meissner@suse.de
- Upgraded to version 40
  - more manpages
  - some new features
  - lots of bugfixes
* Fri Aug  3 2007 meissner@suse.de
- fixed pam module path for ia64 and s390x too.
* Sun Jul 29 2007 meissner@suse.de
- fixed pam module path
* Fri Jul 27 2007 meissner@suse.de
- uphgraded to version 18.
  - TPM support (not yet enabled)
  - added PAM module
* Tue Mar 20 2007 meissner@suse.de
- build on IA64
- fixed compiler warnings
* Tue Mar  6 2007 meissner@suse.de
- fixed build on lib64
* Mon Mar  5 2007 meissner@suse.de
- upgraded to version 10.
  - unlisted enhancements and bugfixes.
* Thu Dec 14 2006 meissner@suse.de
- use lib64 correctly.
- fixed "is used uninitialized" warnings.
* Tue Dec  5 2006 meissner@suse.de
- initial checkin of version 5.
  - userland utilities to control ecryptfs filesystems
